LinkDecision

Struct LinkDecision 

pub struct LinkDecision {
    pub source: NodeId,
    pub target: NodeId,
    pub relation: EdgeKind,
    pub matcher: String,
    pub matcher_version: Version,
    pub score: f32,
    pub confidence: f32,
    pub reasons: Vec<String>,
    pub rejected_alternatives: Vec<RejectedAlternative>,
    pub evidence: Vec<EvidenceRef>,
    pub status: LinkStatus,
}
Versioned and explainable record of a linker match or suppression.

Fields

source: NodeId

Resolved source node.

target: NodeId

Resolved target node.

relation: EdgeKind

Concrete relationship considered by the matcher.

matcher: String

Stable matcher identifier.

matcher_version: Version

Semantic version of the matcher behavior.

score: f32

Normalized raw match score in the inclusive range from zero to one.

confidence: f32

Normalized confidence in the inclusive range from zero to one.

reasons: Vec<String>

Deterministically ordered explanations for the decision.

rejected_alternatives: Vec<RejectedAlternative>

Deterministically ordered candidates that were not selected.

evidence: Vec<EvidenceRef>

Deterministically ordered supporting evidence references.

status: LinkStatus

Final decision state.