pub struct RejectedAlternative {
pub candidate: NodeId,
pub score: f32,
pub reasons: Vec<String>,
}Expand description
Exact candidate considered but not selected by a linker matcher.
Fields
candidate: NodeIdCandidate node identity.
score: f32Normalized matcher score in the inclusive range from zero to one.
reasons: Vec<String>Deterministically ordered reasons the candidate was rejected.